#ifndef THEME_CLOCK_DRAW_H
#define THEME_CLOCK_DRAW_H

/*!
  \file
  \brief テーマ時計の描画

  \author Satofumi KAMIMURA

  $Id$
*/

#include <QWidget>


/*!
  \brief テーマ時計の描画クラス
*/
class ThemeClockDraw : public QWidget {
  Q_OBJECT;

  ThemeClockDraw(const ThemeClockDraw& rhs);
  ThemeClockDraw& operator = (const ThemeClockDraw& rhs);

  struct pImpl;
  std::auto_ptr<pImpl> pimpl;

protected:
  /*!
    \brief 描画イベント処理

    \param event [i/o] イベント
  */
  void paintEvent(QPaintEvent* event);

public:
  /*!
    \brief コンストラクタ

    \param parent [i] 親ウィジット
  */
  ThemeClockDraw(QWidget* parent = 0);
  ~ThemeClockDraw(void);

  /*!
    \brief テーマファイルの読み出し

    \param theme_file [i] テーマファイル

    \retval true 成功
    \retval エラー
  */
  bool loadThemeFile(const QString& theme_file, const char* key = "LMTC");

  /*!
    \brief テーマファイル名を返す

    \return テーマファイル名

    \attention テーマがロードされていない場合は、"" を返す
  */
  const QString getThemeFile(void);

  /*!
    \brief テーマ時計の再描画を行う
  */
  void redraw(void);

  /*!
    \brief 透過領域の取得

    \return 透過領域
  */
  QRegion* getRegion(void);

signals:
  /*!
    \brief 終了シグナルを投げる
  */
  void quit(void);
};

#endif /*! THEME_CLOCK_DRAW_H */
